"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createNumberMask;

function createNumberMask(props) {
  const {
    delimiter = '.',
    precision = 2,
    prefix = [],
    separator = ','
  } = props || {};
  return value => {
    const numericValue = (value === null || value === void 0 ? void 0 : value.replace(/\D+/g, '')) || '';
    let mask = numericValue.split('').map(() => /\d/);

    if (mask.length > precision && precision && separator) {
      mask.splice(-precision, 0, separator);
    }

    const delimiters = Math.ceil((numericValue.length - precision) / 3) - 1;

    if (delimiter) {
      for (let i = 0; i < delimiters; i++) {
        const precisionOffset = precision;
        const separatorOffset = separator ? 1 : 0;
        const thousandOffset = 3 + (delimiter ? 1 : 0);
        const position = -precisionOffset - separatorOffset - i * thousandOffset - 3;
        mask.splice(position, 0, delimiter);
      }
    }

    return [...prefix, ...mask];
  };
}
//# sourceMappingURL=createNumberMask.js.map